/* slurp-download-widget.c
 *
 * Copyright © 2018 Julian Richen <julian@richen.io>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "slurp-download-widget.h"

typedef struct _SlurpDownloadWidgetPrivate
{
    SlurpManager *manager;

    GtkWidget *download_items;
} SlurpDownloadWidgetPrivate;

G_DEFINE_TYPE_WITH_PRIVATE (SlurpDownloadWidget, slurp_download_widget, GTK_TYPE_BIN)

enum {
    PROP_0,
    PROP_MANAGER,
    NUM_PROPERTIES
};

static GParamSpec *properties[NUM_PROPERTIES];

static void
slurp_download_widget_finalize (GObject *object)
{
    SlurpDownloadWidget *self = SLURP_DOWNLOAD_WIDGET (object);
    SlurpDownloadWidgetPrivate *priv = slurp_download_widget_get_instance_private (self);

    g_clear_pointer (&priv->manager, g_object_unref);
    g_clear_pointer (&priv->download_items, g_object_unref);

	G_OBJECT_CLASS (slurp_download_widget_parent_class)->finalize (object);
}

static void
slurp_download_widget_get_property (GObject    *object,
                                    guint       prop_id,
                                    GValue     *value,
                                    GParamSpec *pspec)
{
    SlurpDownloadWidget *self = SLURP_DOWNLOAD_WIDGET (object);
    SlurpDownloadWidgetPrivate *priv = slurp_download_widget_get_instance_private (self);

    switch (prop_id)
    {
        case PROP_MANAGER:
            g_value_set_object (value, priv->manager);
            break;

        default:
            G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
    }
}

static void
slurp_download_widget_set_property (GObject      *object,
                                    guint         prop_id,
                                    const GValue *value,
                                    GParamSpec   *pspec)
{
    SlurpDownloadWidget *self = SLURP_DOWNLOAD_WIDGET (object);
    SlurpDownloadWidgetPrivate *priv = slurp_download_widget_get_instance_private (self);

    switch (prop_id)
    {
        case PROP_MANAGER:
            priv->manager = g_value_dup_object (value);
            break;

        default:
            G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
    }
}

static void
slurp_download_widget_class_init (SlurpDownloadWidgetClass *klass)
{
	GObjectClass *object_class = G_OBJECT_CLASS (klass);
	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);

	object_class->finalize = slurp_download_widget_finalize;
    object_class->get_property = slurp_download_widget_get_property;
    object_class->set_property = slurp_download_widget_set_property;

	/**
	 * SlurpDownloadWidget:manager:
	 *
	 * A SlurpManager.
	 */
    properties[PROP_MANAGER] =
        g_param_spec_object ("manager",
                             "Manager",
                             "A SlurpManager.",
                             SLURP_TYPE_MANAGER,
                             G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);

    g_object_class_install_properties (object_class,
                                       NUM_PROPERTIES,
                                       properties);

	gtk_widget_class_set_template_from_resource (widget_class,
						                         SLURP_GTK_GRESOURCE "/ui/slurp-download-widget.ui");

	gtk_widget_class_bind_template_child_private (widget_class, SlurpDownloadWidget, download_items);
}

static void
slurp_download_widget_init (SlurpDownloadWidget *self)
{
    gtk_widget_init_template (GTK_WIDGET (self));
}

/*
 * *****************************************************************************
 * API
 * *****************************************************************************
 */

SlurpDownloadWidget *
slurp_download_widget_new (SlurpManager *manager)
{
	return g_object_new (SLURP_TYPE_DOWNLOAD_WIDGET,
                         "manager", manager,
                         NULL);
}
