/* slurp-resource.h
 *
 * Copyright © 2017 Julian Richen <julian@richen.io>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SLURP_RESOURCE_H
#define SLURP_RESOURCE_H

#include "slurp-utils.h"

#include <glib-object.h>
#include <glib.h>
#include <gio/gio.h>

G_BEGIN_DECLS

#define SLURP_TYPE_RESOURCE (slurp_resource_get_type())

G_DECLARE_FINAL_TYPE (SlurpResource, slurp_resource, SLURP, RESOURCE, GObject)

struct _SlurpResource
{
    GObject parent_instance;
};

SlurpResource *
slurp_resource_new (void);

void
slurp_resource_set_source (SlurpResource *self,
                           const gchar   *uri);

gchar *
slurp_resource_get_source (SlurpResource *self);

void
slurp_resource_set_target (SlurpResource *self,
                           const gchar   *uri);

gchar *
slurp_resource_get_target (SlurpResource *self);

gboolean
slurp_resource_get_overwrite (SlurpResource *self);

void
slurp_resource_set_overwrite (SlurpResource *self,
                              gboolean       overwrite);

void
slurp_resource_set_total_bytes (SlurpResource *self,
                                guint64       *bytes);

guint64
slurp_resource_get_total_bytes (SlurpResource *self);

void
slurp_resource_set_downloaded_bytes (SlurpResource *self,
                                     guint64       *bytes);

guint64
slurp_resource_get_downloaded_bytes (SlurpResource *self);

guint64
slurp_resource_get_download_speed (SlurpResource *self);

guint64
slurp_resource_get_estimated_time (SlurpResource *self);

void
slurp_resource_update_progress (SlurpResource *self);

G_END_DECLS

#endif /* SLURP_RESOURCE_H */

