/* slurp-resource.c
 *
 * Copyright © 2017 Julian Richen <julian@richen.io>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "slurp-utils.h"

/**
 * slurp_utils_uri_is_directory:
 * @uri: a URI
 *
 * Checks if a supplied @uri is a directory.
 *
 * Returns: %TRUE if uri is a directory, %FALSE if not
 */
gboolean
slurp_utils_uri_is_directory (const gchar *uri)
{
    return g_str_has_suffix (uri, G_DIR_SEPARATOR_S);
}

/**
 * slurp_utils_create_directory:
 * @uri: a URI
 *
 * Creates the directory path of @uri, including the parent directories.
 *
 * Returns: %TRUE the directory path for @uri was created, %FALSE if not
 */
gboolean
slurp_utils_create_directory (const gchar *uri)
{
    gint retval;

// TOOD: Add GError and get errno value from g_mkdir_with_parents()
    if (slurp_utils_uri_is_directory (uri))
        retval = g_mkdir_with_parents (uri, 0700);
    else
        // TODO: More error checking, g_path_get_dirname() can return '.'
        retval = g_mkdir_with_parents (g_path_get_dirname (uri), 0700);

    if (retval == 0)
        return TRUE;

    return FALSE;
}
